enum Realm<'a> {
AutoRealm(AutoRealm<'a>),
CurrentRealm(&'a mut CurrentRealm<'a>),
}Expand description
Helper type to keep AutoRealm and &mut CurrentRealm alive with Deref to JSContext
Variants
AutoRealm(AutoRealm<'a>)
CurrentRealm(&'a mut CurrentRealm<'a>)
Methods from Deref<Target = JSContext>
Sourcepub unsafe fn raw_cx(&mut self) -> *mut JSContext
pub unsafe fn raw_cx(&mut self) -> *mut JSContext
Obtain RawJSContext mutable pointer.
Safety
No NoGC tokens should be constructed while returned pointer is available to user. In practices this means that one should use the result as direct argument to SpiderMonkey function and not store it in variable.
use mozjs::context::*;
use mozjs::jsapi::JSContext as RawJSContext;
fn SM_function_that_can_trigger_gc(_cx: *mut RawJSContext) {}
fn can_trigger_gc(cx: &mut JSContext) {
unsafe { SM_function_that_can_trigger_gc(cx.raw_cx()) } // returned pointer is immediately used
cx.no_gc(); // this is ok because no outstanding raw pointer is alive
}Sourcepub unsafe fn raw_cx_no_gc(&self) -> *mut JSContext
pub unsafe fn raw_cx_no_gc(&self) -> *mut JSContext
Obtain RawJSContext mutable pointer, that will not be used for GC.
Safety
No &mut calls should be done on JSContext while returned pointer is available. In practices this means that one should use the result as direct argument to SpiderMonkey function and not store it in variable.
use mozjs::context::*;
use mozjs::jsapi::JSContext as RawJSContext;
fn SM_function_that_cannot_trigger_gc(_cx: *mut RawJSContext) {}
fn f(cx: &mut JSContext) {
unsafe { SM_function_that_cannot_trigger_gc(cx.raw_cx_no_gc()) } // returned pointer is immediately used
}Trait Implementations