pub(crate) fn ensure_expando_object(
cx: &mut JSContext,
obj: HandleObject<'_>,
expando: MutableHandleObject<'_>,
)Expand description
Get the expando object, or create it if it doesn’t exist yet. Fails on JSAPI failure.
pub(crate) fn ensure_expando_object(
cx: &mut JSContext,
obj: HandleObject<'_>,
expando: MutableHandleObject<'_>,
)Get the expando object, or create it if it doesn’t exist yet. Fails on JSAPI failure.