pub(crate) fn get_expando_object(
obj: HandleObject<'_>,
expando: MutableHandleObject<'_>,
)Expand description
Get the expando object, or null if there is none.
pub(crate) fn get_expando_object(
obj: HandleObject<'_>,
expando: MutableHandleObject<'_>,
)Get the expando object, or null if there is none.